package com.tfis.system.mapper;

import java.util.List;
import com.tfis.system.domain.AircraftSubsystem;

/**
 * 分系统信息管理Mapper接口
 * 
 * @author allen
 * @date 2023-11-23
 */
public interface AircraftSubsystemMapper 
{
    /**
     * 查询分系统信息管理
     * 
     * @param id 分系统信息管理主键
     * @return 分系统信息管理
     */
    public AircraftSubsystem selectAircraftSubsystemById(Long id);

    /**
     * 查询分系统信息管理列表
     * 
     * @param aircraftSubsystem 分系统信息管理
     * @return 分系统信息管理集合
     */
    public List<AircraftSubsystem> selectAircraftSubsystemList(AircraftSubsystem aircraftSubsystem);

    /**
     * 新增分系统信息管理
     * 
     * @param aircraftSubsystem 分系统信息管理
     * @return 结果
     */
    public int insertAircraftSubsystem(AircraftSubsystem aircraftSubsystem);

    /**
     * 修改分系统信息管理
     * 
     * @param aircraftSubsystem 分系统信息管理
     * @return 结果
     */
    public int updateAircraftSubsystem(AircraftSubsystem aircraftSubsystem);

    /**
     * 删除分系统信息管理
     * 
     * @param id 分系统信息管理主键
     * @return 结果
     */
    public int deleteAircraftSubsystemById(Long id);

    /**
     * 批量删除分系统信息管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAircraftSubsystemByIds(Long[] ids);
}
